
/*  ___   ___  ___  _   _  ___   ___   ____ ___  ____  
 * / _ \ /___)/ _ \| | | |/ _ \ / _ \ / ___) _ \|    \ 
 *| |_| |___ | |_| | |_| | |_| | |_| ( (__| |_| | | | |
 * \___/(___/ \___/ \__  |\___/ \___(_)____)___/|_|_|_|
 *                  (____/ 
 * OSOYOO IoT Tutorial: Use OSOYOO IoT APP to collect LED status
 * To run this code, you also need to install following libraries:
 * WifiEsp-master library, download link:https://osoyoo.com/driver/WiFiEsp-master.zip
 * Hardware: OSOYOO MEGA2560 board, MEGA IoT Wifi Shield , LED module
 * Tutorial link: https://osoyoo.com/?p=46253
 * CopyRIGHT www.osoyoo.com
*/


#include <WiFiEsp.h>
#include "OsoyooIOT.h"
const byte ledPin = 2;
const byte button = 3;
volatile byte state = LOW;
// Emulate softserial on pins 6/7 if not present

#include "SoftwareSerial.h"
SoftwareSerial softserial(A9, A8); // A9 to E_TX, A8 to E_RX

char ssid[] = "***";            // your network SSID (name)
char pass[] = "***";        // your network password
int status = WL_IDLE_STATUS;     // the Wifi radio's status

unsigned int localPort = 8888;  // local port to listen on

char packetBuffer[255];          // buffer to hold incoming packet
char reply_on[] = "LED is ON\n";      // a string to send back
char reply_off[]= "LED is OFF\n";      // a string to send back
IPAddress remoteIp=IPAddress(192,168,1,255);
OsoyooIOT udp;

void setup() {
  pinMode(ledPin, OUTPUT);
  pinMode(button, INPUT_PULLUP);
  attachInterrupt(digitalPinToInterrupt(button), blink, RISING);
  Serial.begin(9600); 
 
  Serial.begin(9600);   // initialize serial for debugging
  softserial.begin(115200);
  softserial.write("AT+CIOBAUD=9600\r\n");
  softserial.write("AT+RST\r\n");
  softserial.begin(9600);    // initialize serial for ESP module
  WiFi.init(&softserial);    // initialize ESP module

  // check for the presence of the shield:
  if (WiFi.status() == WL_NO_SHIELD) {
    Serial.println("WiFi shield not present");
    // don't continue:
    while (true);
  }

  // attempt to connect to WiFi network
  while ( status != WL_CONNECTED) {
    Serial.print("Attempting to connect to WPA SSID: ");
    Serial.println(ssid);
    // Connect to WPA/WPA2 network
    status = WiFi.begin(ssid, pass);
  }

  Serial.println("Connected to wifi");
  printWifiStatus();

  Serial.println("\nStarting connection to server...");
  // if you get a connection, report back via serial:
  udp.begin(localPort);

  Serial.print("Listening on port ");
  Serial.println(localPort);

 

}
void blink() {
  state = !state;
  Serial.println("button pressed");
  digitalWrite(ledPin, state);

}
void loop() {
 
  udp.loop();
  if(udp.available()){
    Serial.print("Received packet of size ");
    Serial.println(udp.packetSize());
    Serial.print("From ");
    remoteIp = udp.remoteIP();
    Serial.print(remoteIp);


    Serial.println("Contents:");
    Serial.println(udp.packets());

    // send a reply, to the IP address and port that sent us the packet we received
    //udp.beginPacket(udp.remoteIP(), udp.remotePort());
    char* msg;
    OsoyooCommand myData = udp.read();
    Serial.print("Data Command:");
    String command = String(myData.command);
    Serial.print(command);
    if (command =="F") state = HIGH;
    if (command =="G") state = LOW;
 
    digitalWrite(ledPin,state);
    udp.beginPacket(remoteIp,8888); // send reply packet to port 8888
    if(state==HIGH)  udp.write(reply_on, sizeof(reply_on)-1); 
    else udp.write(reply_off, sizeof(reply_off)-1); 
    udp.endPacket();
  }
 
}


void printWifiStatus() {
  // print the SSID of the network you're attached to:
  Serial.print("SSID: ");
  Serial.println(WiFi.SSID());

  // print your WiFi shield's IP address:
  IPAddress ip = WiFi.localIP();
  Serial.print("IP Address: ");
  Serial.println(ip);

  // print the received signal strength:
  long rssi = WiFi.RSSI();
  Serial.print("signal strength (RSSI):");
  Serial.print(rssi);
  Serial.println(" dBm");
}
